function [rgb,filename]=colortable(name,topcolorname)
% COLORTABLE Return a MATLAB colormap for a COMSOL color table
%
%   MAP = COLORTABLE(NAME) returns the color table (of 256 colors) for
%   NAME, where NAME can be one of the following strings:
%
%   AuroraAustralis, AuroraBorealis, and JupiterAuroraBorealis - resemble the colors
%   in the aurora australis (southern light) aurora borealis (northern light) and 
%   Jupiter's aurora, respectively. 
%   The AuroraAustralis color table spans from white through green and indigo to blue. 
%   The AuroraBorealis color table also spans from white through green and indigo to 
%   blue, but with a larger indigo portion. 
%   The JupiterAuroraBorealis color table spans from black through blue to white.
%
%   Cividis - Uses yellow and blue colors in a color table that is suited for normal
%   vision, a deuteranomaly, or red-green colorblindness.
%
%   Cyclic - A color table that varies the hue component of the hue-saturation-value
%   color model, keeping the saturation and value constant (equal to 1). 
%   The colors begin with red, pass through yellow, green, cyan, blue, magenta, and 
%   finally return to red. This table is particularly useful for displaying periodic 
%   functions and has a sharp color gradient.
%
%   Disco - This color table spans from red through magenta and cyan to blue.
%
%   DiscoLight - Similar to Disco but uses lighter colors.
%
%   GrayScale - A color table that uses no color, only the gray scale varying
%   linearly from black to white.
%
%   GrayPrint - Varies linearly from dark gray (0.95, 0.95, 0.95) to light
%   gray (0.05, 0.05, 0.05). This color table overcomes two disadvantages that the
%   GrayScale color table has when used for printouts on paper, namely that it gives 
%   the impression of being dominated by dark colors, and that white cannot be 
%   distinguished from the background.
%
%   HeatCamera, HeatCameraLight - Colors range from black through blue, magenta, red, 
%   and yellow to white, corresponding to the colors in an image from a heat camera.
%
%   Rainbow - The color ordering in this table corresponds to the wavelengths of the
%   visible part of the electromagnetic spectrum. The colors range through shades of 
%   blue, cyan, green, yellow, and red.
%
%   RainbowLight - Similar to Rainbow, this color table uses lighter colors.
%
%   Spectrum - Similar to the Rainbow color table but includes violet at the small-
%   wavelength end of the visible spectrum. It also includes richer shades of green 
%   to more closely replicate the human perception of visible light.
%
%   Thermal - Ranges from black through red and yellow to white, which corresponds
%   to the colors iron takes as it heats up.
%
%   ThermalEquidistant - Similar to Thermal but uses equal distances from black to
%   red, yellow, and white, which means that the black and red regions become larger.
%
%   Traffic - Spans from green through yellow to red.
%
%   TrafficLight - Similar to Traffic but uses lighter colors.
% 
%   Twilight - uses colors associated with twilight (the illumination of the Earth's 
%   lower atmosphere when the Sun is not directly visible), spanning colors from pink 
%   through white to blue.
%
%   Wave - Ranges linearly from blue to light gray, and then linearly from white to
%   red. When the range of the visualized quantity is symmetric around zero, the 
%   color red or blue indicates whether the value is positive or negative, and the 
%   saturation indicates the magnitude.
%
%   WaveLight - Similar to Wave and ranges linearly from a lighter blue to white -
%   instead of light gray - and then linearly from white to a lighter red.
%
%   Calling colortable is equivalent to calling the corresponding colormap
%   function directly.
%
%   Example:
%     m = colortable('Rainbow');
%     m = rainbow;
%
% See also: AURORAAUSTRALIS, AURORABOREALIS, CIVIDIS, CYCLIC, DISCO, DISCOLIGHT, 
% GRAYPRINT, GRAYSCALE, HEATCAMERA, HEATCAMERALIGHT, JUPITERAURORABOREALIS, 
% RAINBOW, RAINBOWLIGHT, SPECTRUM, THERMAL, THERMALEQUIDISTANT, THERMALLIGHT, 
% TRAFFIC, TRAFFICLIGHT, TWILIGHT, WAVE, WAVELIGHT

%   Copyright 2010-2019 COMSOL
