function [n,f]=mphselectcoords(model,geomtag,coord,entity,varargin)
% MPHSELECTCOORDS Select geometric entity using point coordinates
% 
%   N = MPHSELECTCOORDS(MODEL,GEOMTAG,COORD,ENTITY,...) finds geometry 
%   entity numbers based on their vertex coordinates.
% 
%   One or more coordinate may be provided. The function searches for
%   vertices near these coordinates using a tolerance radius.
%   The list of the entities that are adjacent to such vertices is returned.
% 
%   COORD is a NxM array where N correspond of the number of point to use
%   and M the space dimension of the geometry.
%   ENTITY can be one of 'point', 'edge', 'boundary' or 'domain'. See the 
%   entry MPHSELECTCOORDS in the LiveLink for MATLAB User's Guide for more 
%   information about the entity type definition.
% 
%   Valid property/value pairs include:
%   Property     Value/{Default}            Description
%   -----------------------------------------------------------------------
%   adjnumber    Scalar | {[]}              Adjacent entity number
%   radius       Scalar | {'auto'}          Search radius
%   include      'Any' | {'all'}            Include all vertices or any 
%                                           vertex
% 
%   When a model uses "form an assembly" more than one vertex may have the
%   same coordinate if the coordinate is shared be separate geometric
%   objects. In that case one can use the adjnumber property in order to
%   identify the domain that the vertices should be adjacent to.
% 
%   The radius property is used to specify the radius of the sphere/
%   circle that the search should be within.
%   A small positive radius (based on the geometry size) is used by default
%   in order to compensate for rounding errors.
% 
%   Use the property include when two point coordinates are used. Set it
%   to 'all' to select objects within the search radius of all points.
%   'any' returns objects within the search radius of any points. 
%
% 
%   Example 1: Find geometry entity number 
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%
%     % Return the indices of the point at coordinates:
%     coord = [10e-3 0 10e-3;0 10e-3 10e-3];
%     n = mphselectcoords(model,'geom1',coord','point')
%
%     % Return the indices of the point at coordinates within a search 
%     % radius of 0.011:
%     n = mphselectcoords(model,'geom1',coord','point','radius',0.011)
%
%     % Return the indices of the boundaries that have a vertex within the 
%     % search radius:
%     n = mphselectcoords(model,'geom1',coord','boundary','radius',11e-3)
%
%     % Return the indices of the edges that have a vertex within the 
%     % search radius from all points:
%     coord = [5e-3 0 10e-3;0 5e-3 10e-3];
%     n = mphselectcoords(model,'geom1',coord','edge','radius',6e-3)
%     % Return the indices of the edges that have a vertex within the search
%     % radius from at least one point:
%     n = mphselectcoords(model,'geom1',coord','edge','radius',6e-3,...
%         'include','any')
% 
%   Example 2: Find geometry entity index in an assembly
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Finalize the geometry as an assembly:
%     model.geom('geom1').feature('fin').set('action', 'assembly');
%     model.geom('geom1').run('fin');
% 
%     % Return the indices of the boundaries that have any vertices within 
%     % the search range of a point:
%     coord = [0,0,10e-3];
%     n0 = mphselectcoords(model,'geom1',coord,'boundary')
%
%     % Return the indices of the boundaries that also are adjacent to 
%     % domain 1:
%     n1 = mphselectcoords(model,'geom1',coord,'boundary','adjnumber',1)
% 
%     % Return the indices of the boundaries that also are adjacent to 
%     % domain 2:
%     n1 = mphselectcoords(model,'geom1',coord,'boundary','adjnumber',2)
% 
%   See also: mphgetadj, mphgetcoords, mphselectbox, mphviewselection

%   Copyright 2010-2019 COMSOL
