function [out,sols]=mphsolutioninfo(model,varargin)
% MPHSOLUTIONINFO Get information about solution objects and data sets
% containing given parameters
%
%   INFO = MPHSOLUTIONINFO(MODEL) returns information about all solution
%   object and solution data set combinations.
%
%   DATASET = MPHSOLUTIONINFO(MODEL,'PARAMETERS',{{Ei, Vi, TOLi},...},...)
%   returns information about solution object and solution data set
%   containing the given inner/outer solution parameter Ei with the value
%   equal to Vi within the tolerance TOLi.
%
%   Valid property/value pairs include:
%   Property      Value/{Default}       Description
%   -----------------------------------------------------------------------
%   cellmap       {'off'} | 'on'        Set to return a cell version of
%                                       the map with headers
%   dataset       String                Data set tag
%   parameters    Cell | Cell array     Filter parameters/values/tolerances
%   soltag        String | String cell  Solution node tag
%                 array | {''}
%   sort          String | Scalar |     Sorts the map by column number or
%                 {'auto'}              header tag
%
%   INFO is a structure with the following fields:
%   Field          Description
%   -----------------------------------------------------------------------
%   solutions      List of matched solution tags.
%   sol#           Substructure containing information related to
%                  solution number #.
%
%   The substructure INFO.sol# contains the following fields:
%   Field          Description
%   -----------------------------------------------------------------------
%   dataset        Tag of the solution data set.
%   study          Tag of the study associated to the solution.
%   sequencetype   Type of solution node.
%   cellmap        Cellmap describing the connections between
%                  parameters and inner-/outer-solution numbers.
%   values         Parameter values used in the solution.
%   parameters     Parameter names used in the solution.
%   mapheaders     Headers for the map.
%   map            Map describing the connections between parameters
%                  and inner-/outer-solution numbers.
%
%   Example:
%      % Load model_tutorial_llmatlab.mph:
%      model = mphopen('model_tutorial_llmatlab');
%      % Create a study combining a parametric sweep and a transient
%      % study step:
%      std = model.study.create('std');
%      param = std.feature.create('param','Parametric');
%      time = std.feature.create('time','Transient');
%      % Set the time stepping and the parametric sweep parameters:
%      time.set('tlist', 'range(0,1,25)');
%      param.setIndex('pname','power',0).setIndex('plistarr','30 60 90', 0);
%      % Run the study:
%      std.run;
%
%      % Retreive the solution information corresponding to power = 30W:
%      info = mphsolutioninfo(model,'parameters',{'power',30,0})
%
%      % Retreive the solution information corresponding to power = 90 W
%      % and around t = 10.4 sec. and its associated solution data set:
%      info = mphsolutioninfo(model,'parameters',{{'power',90,0},...
%         {'t',10.4,0.5}})
%      % Get the solution solution data set associated:
%      dset = info.sol2.dataset
%      % Get the inner and outer solution number:
%      solnum = info.sol2.map(:,end-1)
%      outersolnum = info.sol2.map(:,end)
%
%   See also: mphgetu, mphxmeshinfo, mphsolinfo

%   Copyright 2012-2019 COMSOL
